Adagios - ObjectBrowser
Author: Tomas Edwardsson, Pall Sigurdsson
Description: Adagios - Nagios Configuration Made Easy

glyph-glass
glyph-leaf
glyph-dog
glyph-user
glyph-girl
glyph-car
glyph-user-add
glyph-user-remove
glyph-film
glyph-magic
glyph-envelope
glyph-camera
glyph-heart
glyph-beach-umbrella
glyph-train
glyph-print
glyph-bin
glyph-music
glyph-note
glyph-cogwheel
glyph-home
glyph-snowflake
glyph-fire
glyph-cogwheels
glyph-parents
glyph-binoculars
glyph-road
glyph-search
glyph-cars
glyph-notes-2
glyph-pencil
glyph-bus
glyph-wifi-alt
glyph-luggage
glyph-old-man
glyph-woman
glyph-file
glyph-credit
glyph-airplane
glyph-notes
glyph-stats
glyph-charts
glyph-pie-chart
glyph-group
glyph-keys
glyph-calendar
glyph-router
glyph-camera-small
glyph-dislikes
glyph-star
glyph-link
glyph-eye-open
glyph-eye-close
glyph-alarm
glyph-clock
glyph-stopwatch
glyph-projector
glyph-history
glyph-truck
glyph-cargo
glyph-compass
glyph-keynote
glyph-attach
glyph-power
glyph-lightbulb
glyph-tag
glyph-tags
glyph-cleaning
glyph-ruller
glyph-gift
glyph-umbrella
glyph-book
glyph-bookmark
glyph-signal
glyph-cup
glyph-stroller
glyph-headphones
glyph-headset
glyph-warning-sign
glyph-signal
glyph-retweet
glyph-refresh
glyph-roundabout
glyph-random
glyph-heat
glyph-repeat
glyph-display
glyph-log-book
glyph-adress-book
glyph-magnet
glyph-table
glyph-adjust
glyph-tint
glyph-crop
glyph-vector-path-square
glyph-vector-path-circle
glyph-vector-path-polygon
glyph-vector-path-line
glyph-vector-path-curve
glyph-vector-path-all
glyph-font
glyph-italic
glyph-bold
glyph-text-underline
glyph-text-strike
glyph-text-height
glyph-text-width
glyph-text-resize
glyph-left-indent
glyph-right-indent
glyph-align-left
glyph-align-center
glyph-align-right
glyph-justify
glyph-list
glyph-text-smaller
glyph-text-bigger
glyph-embed
glyph-embed-close
glyph-adjust
glyph-message-full
glyph-message-empty
glyph-message-in
glyph-message-out
glyph-message-plus
glyph-message-minus
glyph-message-ban
glyph-message-flag
glyph-message-lock
glyph-message-new
glyph-inbox
glyph-inbox-plus
glyph-inbox-minus
glyph-inbox-lock
glyph-inbox-in
glyph-inbox-out
glyph-computer-locked
glyph-computer-service
glyph-computer-proces
glyph-phone
glyph-database-lock
glyph-database-plus
glyph-database-minus
glyph-database-ban
glyph-folder-open
glyph-folder-plus
glyph-folder-minus
glyph-folder-lock
glyph-folder-flag
glyph-folder-new
glyph-check
glyph-edit
glyph-new-window
glyph-more-windows
glyph-show-big-thumbnails
glyph-show-thumbnails
glyph-show-thumbnails-with-lines
glyph-show-lines
glyph-playlist
glyph-picture
glyph-imac
glyph-macbook
glyph-ipad
glyph-iphone
glyph-iphone-transfer
glyph-iphone-exchange
glyph-ipod
glyph-ipod-shuffle
glyph-ear-plugs
glyph-albums
glyph-step-backward
glyph-fast-backward
glyph-rewind
glyph-play
glyph-pause
glyph-stop
glyph-forward
glyph-fast-forward
glyph-step-forward
glyph-eject
glyph-facetime-video
glyph-download-alt
glyph-mute
glyph-volume-down
glyph-volume-up
glyph-screenshot
glyph-move
glyph-more
glyph-brightness-reduce
glyph-brightness-increase
glyph-circle-plus
glyph-circle-minus
glyph-circle-remove
glyph-circle-ok
glyph-circle-question-mark
glyph-circle-info
glyph-circle-exclamation-mark
glyph-remove
glyph-ok
glyph-ban
glyph-download
glyph-upload
glyph-shopping-cart
glyph-lock
glyph-unlock
glyph-electricity
glyph-ok-2
glyph-remove-2
glyph-cart-out
glyph-cart-in
glyph-left-arrow
glyph-right-arrow
glyph-down-arrow
glyph-up-arrow
glyph-resize-small
glyph-resize-full
glyph-circle-arrow-left
glyph-circle-arrow-right
glyph-circle-arrow-top
glyph-circle-arrow-down
glyph-play-button
glyph-unshare
glyph-share
glyph-thin-right-arrow
glyph-thin-arrow-left
glyph-bluetooth
glyph-euro
glyph-usd
glyph-bp
glyph-retweet-2
glyph-moon
glyph-sun
glyph-cloud
glyph-direction
glyph-brush
glyph-pen
glyph-zoom-in
glyph-zoom-out
glyph-pin
glyph-riflescope
glyph-rotation-lock
glyph-flash
glyph-google-maps
glyph-anchor
glyph-conversation
glyph-chat
glyph-male
glyph-female
glyph-asterisk
glyph-divide
glyph-snorkel-diving
glyph-scuba-diving
glyph-oxygen-bottle
glyph-fins
glyph-fishes
glyph-boat
glyph-delete-point
glyph-sheriffs--star
glyph-qrcode
glyph-barcode
glyph-pool
glyph-buoy
glyph-spade
glyph-bank
glyph-vcard
glyph-electrical-plug
glyph-flag
glyph-credit-card
glyph-keyboard-wireless
glyph-keyboard-wired
glyph-shield
glyph-ring
glyph-cake
glyph-drink
glyph-beer
glyph-fast-food
glyph-cutlery
glyph-pizza
glyph-birthday-cake
glyph-tablet
glyph-settings
glyph-bullets
glyph-cardio
glyph-t-shirt
glyph-pants
glyph-sweater
glyph-fabric
glyph-leather
glyph-scissors
glyph-podium
glyph-skull
glyph-celebration
glyph-tea-kettle
glyph-french-press
glyph-coffe-cup
glyph-pot
glyph-grater
glyph-kettle
glyph-hospital
glyph-hospital-h
glyph-microphone
glyph-webcam
glyph-temple-christianity-church
glyph-temple-islam
glyph-temple-hindu
glyph-temple-buddhist
glyph-electrical-socket-eu
glyph-electrical-socket-us
glyph-bomb
glyph-comments
glyph-flower
glyph-baseball
glyph-rugby
glyph-ax
glyph-table-tennis
glyph-bowling
glyph-tree-conifer
glyph-tree-deciduous
glyph-more-items
glyph-sort
glyph-filter
glyph-gamepad
glyph-playing-dices
glyph-calculator
glyph-tie
glyph-wallet
glyph-share
glyph-sampler
glyph-piano
glyph-web-browser
glyph-blog
glyph-dashboard
glyph-certificate
glyph-bell
glyph-candle
glyph-pin-classic
glyph-iphone-shake
glyph-pin-flag
glyph-turtle
glyph-rabbit
glyph-globe
glyph-briefcase
glyph-hdd
glyph-thumbs-up
glyph-thumbs-down
glyph-hand-right
glyph-hand-left
glyph-hand-up
glyph-hand-down
glyph-fullscreen
glyph-shopping-bag
glyph-book-open
glyph-nameplate
glyph-nameplate-alt
glyph-vases
glyph-announcement
glyph-dumbbell
glyph-suitcase
glyph-file-import
glyph-file-export
glyph-pinterest
glyph-dropbox
glyph-google+-alt
glyph-jolicloud
glyph-yahoo
glyph-blogger
glyph-picasa
glyph-amazon
glyph-tumblr
glyph-wordpress
glyph-instapaper
glyph-evernote
glyph-xing
glyph-zootool
glyph-dribbble
glyph-deviantart
glyph-read-it-later
glyph-linked-in
glyph-forrst
glyph-pinboard
glyph-behance
glyph-github
glyph-youtube
glyph-skitch
glyph-4square
glyph-quora
glyph-google-plus
glyph-spootify
glyph-stumbleupon
glyph-readability
glyph-facebook
glyph-twitter-t
glyph-twitter
glyph-buzz
glyph-vimeo
glyph-flickr
glyph-last-fm
glyph-rss
glyph-skype
glyph-e-mail